
Custom Scoring Functions
========================

.. contents::
    :local:

Classification Scores
---------------------

.. autofunction:: lightmlboard.metrics.classification.multi_label_jaccard

Regression Scores
-----------------

.. autofunction:: lightmlboard.metrics.regression_custom.l1_reg_max
